@@ -267,7 +267,6 @@ module Aws
             'AppRunner' => 'apprunner',
             'AppStream' => 'appstream2',
             'AppSync' => 'appsync',
-            'AppTest' => 'apptest',
             'Appflow' => 'appflow',
             'ApplicationAutoScaling' => 'application-autoscaling',
             'ApplicationCostProfiler' => 'application-cost-profiler',
@@ -344,6 +343,7 @@ module Aws
             'Comprehend' => 'comprehend',
             'ComprehendMedical' => 'comprehendmedical',
             'ComputeOptimizer' => 'compute-optimizer',
+            'ComputeOptimizerAutomation' => 'aco-automation',
             'ConfigService' => 'config',
             'Connect' => 'connect',
             'ConnectCampaignService' => 'connect-campaigns',
@@ -394,7 +394,6 @@ module Aws
             'ElasticBeanstalk' => 'elasticbeanstalk',
             'ElasticLoadBalancing' => 'elasticloadbalancing',
             'ElasticLoadBalancingV2' => 'elasticloadbalancing',
-            'ElasticTranscoder' => 'elastictranscoder',
             'ElasticsearchService' => 'es',
             'EntityResolution' => 'entityresolution',
             'EventBridge' => 'events',
@@ -440,7 +439,6 @@ module Aws
             'IoTDeviceAdvisor' => 'api.iotdeviceadvisor',
             'IoTEvents' => 'iotevents',
             'IoTEventsData' => 'data.iotevents',
-            'IoTFleetHub' => 'api.fleethub.iot',
             'IoTFleetWise' => 'iotfleetwise',
             'IoTJobsDataPlane' => 'data.jobs.iot',
             'IoTManagedIntegrations' => 'api.iotmanagedintegrations',
@@ -478,12 +476,11 @@ module Aws
             'Lightsail' => 'lightsail',
             'LocationService' => 'geo',
             'LookoutEquipment' => 'lookoutequipment',
-            'LookoutMetrics' => 'lookoutmetrics',
-            'LookoutforVision' => 'lookoutvision',
             'MPA' => 'mpa',
             'MQ' => 'mq',
             'MTurk' => 'mturk-requester',
             'MWAA' => 'airflow',
+            'MWAAServerless' => 'airflow-serverless',
             'MachineLearning' => 'machinelearning',
             'Macie2' => 'macie2',
             'MailManager' => 'mail-manager',
@@ -524,6 +521,7 @@ module Aws
             'NetworkMonitor' => 'networkmonitor',
             'Notifications' => 'notifications',
             'NotificationsContacts' => 'notifications-contacts',
+            'NovaAct' => 'nova-act',
             'OAM' => 'oam',
             'OSIS' => 'osis',
             'ObservabilityAdmin' => 'observabilityadmin',
@@ -536,6 +534,9 @@ module Aws
             'PCS' => 'pcs',
             'PI' => 'pi',
             'Panorama' => 'panorama',
+            'PartnerCentralAccount' => 'partnercentral-account',
+            'PartnerCentralBenefits' => 'partnercentral-benefits',
+            'PartnerCentralChannel' => 'partnercentral-channel',
             'PartnerCentralSelling' => 'partnercentral-selling',
             'PaymentCryptography' => 'controlplane.payment-cryptography',
             'PaymentCryptographyData' => 'dataplane.payment-cryptography',
@@ -556,8 +557,6 @@ module Aws
             'QApps' => 'data.qapps',
             'QBusiness' => 'qbusiness',
             'QConnect' => 'wisdom',
-            'QLDB' => 'qldb',
-            'QLDBSession' => 'session.qldb',
             'QuickSight' => 'quicksight',
             'RAM' => 'ram',
             'RDS' => 'rds',
@@ -573,10 +572,10 @@ module Aws
             'ResourceExplorer2' => 'resource-explorer-2',
             'ResourceGroups' => 'resource-groups',
             'ResourceGroupsTaggingAPI' => 'tagging',
-            'RoboMaker' => 'robomaker',
             'RolesAnywhere' => 'rolesanywhere',
             'Route53' => 'route53',
             'Route53Domains' => 'route53domains',
+            'Route53GlobalResolver' => 'route53globalresolver',
             'Route53Profiles' => 'route53profiles',
             'Route53RecoveryCluster' => 'route53-recovery-cluster',
             'Route53RecoveryControlConfig' => 'route53-recovery-control-config',
@@ -606,6 +605,7 @@ module Aws
             'SageMakerGeospatial' => 'sagemaker-geospatial',
             'SageMakerMetrics' => 'metrics.sagemaker',
             'SageMakerRuntime' => 'runtime.sagemaker',
+            'SageMakerRuntimeHTTP2' => 'runtime.sagemaker',
             'SagemakerEdgeManager' => 'edge.sagemaker',
             'SavingsPlans' => 'savingsplans',
             'Scheduler' => 'scheduler',
@@ -620,6 +620,7 @@ module Aws
             'ServiceQuotas' => 'servicequotas',
             'Shield' => 'shield',
             'Signer' => 'signer',
+            'Signin' => 'signin',
             'SimSpaceWeaver' => 'simspaceweaver',
             'SimpleDB' => 'sdb',
             'SnowDeviceManagement' => 'snow-device-management',
@@ -650,6 +651,7 @@ module Aws
             'WAFRegional' => 'waf-regional',
             'WAFV2' => 'wafv2',
             'WellArchitected' => 'wellarchitected',
+            'Wickr' => 'admin.wickr',
             'WorkDocs' => 'workdocs',
             'WorkMail' => 'workmail',
             'WorkMailMessageFlow' => 'workmailmessageflow',
